require_plugin

Function require_plugin 

pub fn require_plugin<Args: PandaArgs>(plugin: &Args)
Require a plugin to be loaded, and if it isn’t loaded load it with the given arguments. If the plugin is already loaded the arguments will be discarded.