Module plugins

Module plugins 

Bindings for various built-in PANDA plugins

Modules

cosi
Bindings and helpers for working with the OSI2 plugin, allowing kernel introspection via Volatility 3 Profiles.
glib
glib wrappers for supporting glib-based plugins
guest_plugin_manager
Bindings for the guest plugin manager
hooks
Bindings for the PANDA ‘hooks’ plugin, enabling the ability to add callbacks for when a certain instruction is hit.
hooks2
Raw Rust bindings for hooks2 plugin
osi
Bingings for the OSI (Operating System Introspection) plugin
proc_start_linux
Raw Rust bindings for proc_start_linux plugin
syscalls2
Rust bindings to syscalls2

Structs

Plugin
A wrapper for a dynamic library loaded as a PANDA plugin. Is used internally by the plugin_import macro to manage loading/unloading PANDA plugins lazily.