pub struct VolatilityBaseType { /* private fields */ }Expand description
A base/primitive type within a volatility profile
Can be obtained via the base_type_from_name function.
Note: This type is opaque due to having an undefined layout and thus may only be accessed behind a reference.
Implementations
Sourceimpl VolatilityBaseType
impl VolatilityBaseType