Struct panda::plugins::proc_start_linux::AuxvValues[][src]

#[repr(C)]
pub struct AuxvValues {
Show 29 fields pub argc: c_int, pub argv_ptr_ptr: target_ulong, pub arg_ptr: [target_ulong; 10], pub argv: [[u8; 256]; 10], pub envc: c_int, pub env_ptr_ptr: target_ulong, pub env_ptr: [target_ulong; 20], pub envp: [[u8; 256]; 20], pub execfn_ptr: target_ulong, pub execfn: [u8; 256], pub phdr: target_ulong, pub entry: target_ulong, pub ehdr: target_ulong, pub hwcap: target_ulong, pub hwcap2: target_ulong, pub pagesz: target_ulong, pub clktck: target_ulong, pub phent: target_ulong, pub phnum: target_ulong, pub base: target_ulong, pub flags: target_ulong, pub uid: target_ulong, pub euid: target_ulong, pub gid: target_ulong, pub egid: target_ulong, pub secure: bool, pub random: target_ulong, pub platform: target_ulong, pub program_header: target_ulong,
}
A struct representing the contents of the Auxilary Vector, the information provided by the kernel when starting up a new process.

Resources on the auxilary vector:

Fields

argc: c_intargv_ptr_ptr: target_ulongarg_ptr: [target_ulong; 10]argv: [[u8; 256]; 10]envc: c_intenv_ptr_ptr: target_ulongenv_ptr: [target_ulong; 20]envp: [[u8; 256]; 20]execfn_ptr: target_ulongexecfn: [u8; 256]phdr: target_ulongentry: target_ulongehdr: target_ulonghwcap: target_ulonghwcap2: target_ulongpagesz: target_ulongclktck: target_ulongphent: target_ulongphnum: target_ulongbase: target_ulongflags: target_ulonguid: target_ulongeuid: target_ulonggid: target_ulongegid: target_ulongsecure: boolrandom: target_ulongplatform: target_ulongprogram_header: target_ulong

Implementations