Module panda::plugins::syscalls2 [−][src]
Rust bindings to syscalls2
Not intended to be used directly, but is used internally for the callbacks in on_sys
Structs
Traits
A trait for expressing the plugin-to-plugin callbacks provided by
the given plugin. See panda::PppCallback for more information,
as this is intended to be used as an extension trait for it.