Struct panda::plugins::syscalls2::SYSCALLS [−][src]
pub struct SYSCALLS { /* fields omitted */ }Methods from Deref<Target = Syscalls2>
Load the plugin and initialize it if it hasn’t been loaded already.
pub struct SYSCALLS { /* fields omitted */ }Load the plugin and initialize it if it hasn’t been loaded already.