Module panda::plugins[][src]

Modules

glib wrappers for supporting glib-based plugins

Bindings for the PANDA ‘hooks’ plugin, enabling the ability to add callbacks for when a certain instruction is hit.

Raw Rust bindings for hooks2 plugin

Bingings for the OSI (Operating System Introspection) plugin

Raw Rust bindings for proc_start_linux plugin

Rust bindings to syscalls2

Structs

A wrapper for a dynamic library loaded as a PANDA plugin. Is used internally by the plugin_import macro to manage loading/unloading PANDA plugins lazily.